@@ -449,6 +449,14 @@ class PoolLoggingTest(fixtures.TestBase):
         conn.close()
         conn = None
 
+        conn = q.connect()
+        conn._close_special(transaction_reset=True)
+        conn = None
+
+        conn = q.connect()
+        conn._close_special(transaction_reset=False)
+        conn = None
+
         conn = q.connect()
         conn = None
         del conn
@@ -460,13 +468,19 @@ class PoolLoggingTest(fixtures.TestBase):
             [
                 "Created new connection %r",
                 "Connection %r checked out from pool",
-                "Connection %r being returned to pool%s",
+                "Connection %r being returned to pool",
                 "Connection %s rollback-on-return",
                 "Connection %r checked out from pool",
-                "Connection %r being returned to pool%s",
+                "Connection %r being returned to pool",
                 "Connection %s rollback-on-return",
                 "Connection %r checked out from pool",
-                "Connection %r being returned to pool%s",
+                "Connection %r being returned to pool",
+                "Connection %s reset, transaction already reset",
+                "Connection %r checked out from pool",
+                "Connection %r being returned to pool",
+                "Connection %s rollback-on-return",
+                "Connection %r checked out from pool",
+                "Connection %r being returned to pool",
                 "Connection %s rollback-on-return",
                 "%s connection %r",
             ]
